@@ -5,7 +5,7 @@ from .ctx import split_and_load
 from .fit import fit_wrapper
 from .init import load_net, net_initialize
 from .lr_scheduler import get_lr_scheduler
-from .optimizer_cfg import get_optimizer_cfg
+from longling.ML.DL import get_optimizer_cfg
 from .persistence import save_params
 from .toolbox import get_default_toolbox
 from .trainer import get_trainer
